@@ -8,7 +8,7 @@ use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 use Tags::HTML::Element::Utils qw(tags_boolean tags_data tags_value);
 
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 sub _cleanup {
 	my $self = shift;
@@ -26,7 +26,7 @@ sub _init {
 		|| ! blessed($button)
 		|| ! $button->isa('Data::HTML::Element::Button')) {
 
-		err "Input object must be a 'Data::HTML::Element::Button' instance.";
+		err "Button object must be a 'Data::HTML::Element::Button' instance.";
 	}
 
 	$self->{'_button'} = $button;
@@ -195,7 +195,9 @@ Returns undef.
          From Tags::HTML::new():
                  Parameter 'css' must be a 'CSS::Struct::Output::*' class.
                  Parameter 'tags' must be a 'Tags::Output::*' class.
-         Input object must be a 'Data::HTML::Element::Button' instance.
+
+ init():
+         Button object must be a 'Data::HTML::Element::Button' instance.
 
  process():
          From Tags::HTML::process():
@@ -291,6 +293,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
